==> libxfce4util_4.17.2.orig.tar.bz2: libxfce4util-4.17.2/libxfce4util/libxfce4util.h <==
/* $Id$ */
/*-
 * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 */

#ifndef __LIBXFCE4UTIL_LIBXFCE4UTIL_H__
#define __LIBXFCE4UTIL_LIBXFCE4UTIL_H__

#define LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H

#include <libxfce4util/libxfce4util-config.h>

#include <libxfce4util/xfce-debug.h>
#include <libxfce4util/xfce-fileutils.h>
#include <libxfce4util/xfce-generics.h>
#include <libxfce4util/xfce-i18n.h>
#include <libxfce4util/xfce-kiosk.h>
#include <libxfce4util/xfce-license.h>
#include <libxfce4util/xfce-miscutils.h>
#include <libxfce4util/xfce-posix-signal-handler.h>
#include <libxfce4util/xfce-rc.h>
#include <libxfce4util/xfce-resource.h>
#include <libxfce4util/xfce-utf8.h>
#include <libxfce4util/xfce-gio-extensions.h>
#include <libxfce4util/xfce-string.h>

#undef LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H

#endif  /* !__LIBXFCE4UTIL_LIBXFCE4UTIL_H__ */

==> libxfce4util_4.19.3.orig.tar.bz2: libxfce4util-4.19.3/libxfce4util/libxfce4util.h <==
/* $Id$ */
/*-
 * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 */

#ifndef __LIBXFCE4UTIL_LIBXFCE4UTIL_H__
#define __LIBXFCE4UTIL_LIBXFCE4UTIL_H__

#define _LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H

#include <libxfce4util/libxfce4util-config.h>

#include <libxfce4util/xfce-consolekit.h>
#include <libxfce4util/xfce-debug.h>
#include <libxfce4util/xfce-fileutils.h>
#include <libxfce4util/xfce-generics.h>
#include <libxfce4util/xfce-gio-extensions.h>
#include <libxfce4util/xfce-i18n.h>
#include <libxfce4util/xfce-kiosk.h>
#include <libxfce4util/xfce-license.h>
#include <libxfce4util/xfce-miscutils.h>
#include <libxfce4util/xfce-posix-signal-handler.h>
#include <libxfce4util/xfce-rc.h>
#include <libxfce4util/xfce-resource.h>
#include <libxfce4util/xfce-string.h>
#include <libxfce4util/xfce-systemd.h>
#include <libxfce4util/xfce-utf8.h>

#undef _LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H

#endif  /* !__LIBXFCE4UTIL_LIBXFCE4UTIL_H__ */
